@@ -17,6 +17,17 @@ class DoublyRobustEstimator:
     Estimates the expected reward for each arm, applies a correction for the actions that
     were chosen, and converts the problem to const-sensitive classification, on which the
     base algorithm is then fit.
+
+    Note
+    ----
+    If following these docs to the letter about what to pass under each argument,
+    this implementation will be theoretically incorrect as this whole library
+    doesn't follow the paradigm of producing probabilities of choosing actions, nor of
+    estimating probabilities of a previous policy.
+    Instead, it uses estimated expected rewards (that is, the rows of the estimations
+    don't sum to 1), but nevertheless, this is likely to still produce an improvement
+    over a naive approach. One may still supply post-hoc estimated probabilities if
+    feasible though.
     
     Note
     ----
@@ -33,7 +44,7 @@ class DoublyRobustEstimator:
     output a number in the range :math:`[0,1]`.
     
     This technique is meant for the case of contiunous rewards in the :math:`[0,1]` interval,
-    but here it is used for the case of discrete rewards :math:`\{0,1\}`, under which it performs
+    but here it is used for the case of discrete rewards :math:`\\{0,1\\}`, under which it performs
     poorly. It is not recommended to use, but provided for comparison purposes.
     
     
@@ -50,7 +61,7 @@ class DoublyRobustEstimator:
     they were chosen they resulted in a reward, or never resulted in a reward. In such cases,
     this function includes the option to impute the "predictions" for them (which would otherwise
     always be exactly zero or one regardless of the context) by replacing them with random
-    numbers :math:`\sim \text{Beta}(3,1)` or :math:`\sim \text{Beta}(1,3)` for the cases of
+    numbers :math:`\\sim \\text{Beta}(3,1)` or :math:`\\sim \\text{Beta}(1,3)` for the cases of
     always good and always bad.
     
     This is just a wild idea though, and doesn't guarantee reasonable results in such siutation.
@@ -164,6 +175,10 @@ class DoublyRobustEstimator:
             Rewards that were observed for the chosen actions. Must be binary rewards 0/1.
         p : array (n_samples)
             Reward estimates for the actions that were chosen by the policy.
+
+            Note that, in theory, this should be an estimate of the probabilities that the
+            actions in ``a`` would have been taken under the policy that chose these actions,
+            but passing reward estimates in its place might still produce reasonable results.
         """
         try:
             from costsensitive import RegressionOneVsRest, WeightedAllPairs
