@@ -148,15 +148,18 @@ def _check_beta_prior(beta_prior, nchoices, for_ucb=False):
                 raise ValueError("Invalid value for 'beta_prior'.")
         out = beta_prior
     else:
-        assert len(beta_prior) == 2
-        assert len(beta_prior[0]) == 2
-        assert isinstance(beta_prior[1], int)
-        assert isinstance(beta_prior[0][0], (int, float))
-        assert isinstance(beta_prior[0][1], (int, float))
-        assert (beta_prior[0][0] > 0.) and (beta_prior[0][1] > 0.)
+        _check_beta_prior_single(beta_prior)
         out = beta_prior
     return out
 
+def _check_beta_prior_single(beta_prior):
+    assert len(beta_prior) == 2
+    assert len(beta_prior[0]) == 2
+    assert isinstance(beta_prior[1], int)
+    assert isinstance(beta_prior[0][0], (int, float))
+    assert isinstance(beta_prior[0][1], (int, float))
+    assert (beta_prior[0][0] > 0.) and (beta_prior[0][1] > 0.)
+
 def _check_smoothing(smoothing, nchoices):
     if smoothing is None:
         return None
@@ -701,7 +704,7 @@ class _OneVsRest:
                  smooth=False, noise_to_smooth=True, assume_un=False,
                  partialfit=False, refit_buffer=0, deep_copy=False,
                  force_fit=False, force_counters=False,
-                 prev_ovr=None, warm=False,
+                 prev_ovr=None,
                  force_unfit_predict=False,
                  arms_to_update=None,
                  njobs=1):
@@ -1113,7 +1116,6 @@ class _LogisticUCB_n_TS_single:
         self.lambda_ = lambda_
         self.ts = ts
         self.ts_from_ci = ts_from_ci
-        self.warm_start = True
         self.sample_unique = bool(sample_unique)
         self.n_presampled = n_presampled
         self.random_state = _check_random_state(random_state)
